@@ -19,7 +19,6 @@ personselector = os.path.join(my_path, '../templates/personselector.hbs')
 dropdown_menu = os.path.join(my_path, '../templates/dropdown_menu.hbs')
 table_select = os.path.join(my_path, '../templates/table_select.hbs')
 
-
 compiler = Compiler()
 helpers = {'header': _header, 'body': _body, 'footer': _footer}
 
@@ -37,7 +36,7 @@ smsTypes = dict(
      RADIOBUTTON = 'radiobutton',
      PERSONSELECTOR = 'personselector',
      DROPDOWN_MENU = 'dropdown_menu',
-     TABLE_SELECT = 'table_select'
+     TABLE_SELECT = 'table_select',
 )
 
 compiledTemplates = {}
@@ -68,6 +67,8 @@ def render(message, smsType):
         compile_templates()
     if smsType == 'table_select':
         context = {'table' : message}
+    elif smsType == 'complex_form':
+        context = {'complex_form': message}
     else:
         context = {'message':message}
     template = compiler.compile(compiledTemplates[smsType])
@@ -80,3 +81,20 @@ def renderInBot(message, smsType):
 def renderInApp(message, smsType):
     compiledMessage = render(message, smsType)
     return wrapByMessageMLTags(compiledMessage)
+
+def renderComplexForm(message, formId):
+    form = ''
+    elements = {'button': renderInBot,
+                'textfield': renderInBot,
+                'textarea': renderInBot,
+                'checkbox': renderInBot,
+                'radiobutton': renderInBot,
+                'dropdown_menu': renderInBot,
+                'personselector': renderInBot,
+                'table_select': renderInBot}
+
+    for dic in message:
+        for type, data in dic.items():
+            form += elements[type](data, smsTypes[type.upper()])
+
+    return '<messageML><form id=\"{}\">'.format(formId) + form + '</form></messageML>'
